@@ -45,6 +45,7 @@
         }
 
         if (do.ellipse) {
+            .error_if_no_mass_because("ellipses")
             p <- p + stat_ellipse(
                 data = data,
                 aes(x = .data[[x.by]], y = .data[[y.by]], colour = .data[[color.by]]),
@@ -79,6 +80,7 @@
     # Add contours based on the density of data points
     # (Dim and Scatter plots)
 
+    .error_if_no_mass_because("contours")
     p + geom_density_2d(
         data = data,
         mapping = aes(x = .data[[x.by]], y = .data[[y.by]]),
